sequencetools.split_sequence_cyclically_by_weights_without_overhang
===================================================================

.. autofunction:: abjad.tools.sequencetools.split_sequence_cyclically_by_weights_without_overhang.split_sequence_cyclically_by_weights_without_overhang
